
# Waalaxy Connector

> Waalaxy


🔗 https://www.waalaxy.com/fr/

# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Catch profile**](docs/catch_profile.md) | Imports the visited profiles, in synchronization with the Waalaxy campaign (Visit + CRM Sync) |


</p>